##  Overview
A conditional attribute is a field or relation in a fact sheet that appears or becomes active only when a specific value is selected in another related field, known as the activator. This gives you control over visibility of specific fields or relations, ensuring they are displayed or activated only when relevant. This creates a clear and straightforward experience for end users while collecting data.
Conditional attributes also enable you to create attributes that are specific to particular subtypes and limit existing attributes to particular subtypes. This helps streamline fact sheet subtype management by ensuring that each subtype contains only the necessary fields, making it easier to manage and understand. To learn more about subtype management, see [Fact Sheet Subtype Management](https://help.sap.com/docs/leanix/ea/fact-sheet-subtype-management?locale=en-US&state=PRODUCTION&version=CLOUD "Fact Sheet subtype management enables admins to create subtypes easily and tailor attributes for specific subtypes using conditional attributes.").
